Welcome to Python Kaos Utils's documentation!
=============================================

Set of utilities and helpers for rapid development of Python applications

Getting Started
===============

Install::

    pip install py-kaos-utils

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   argparse
   string
   logging
   mixins
   pagination

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
